summaryrefslogtreecommitdiff
path: root/src/components/include/application_manager/application_manager.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/components/include/application_manager/application_manager.h')
-rw-r--r--src/components/include/application_manager/application_manager.h30
1 files changed, 15 insertions, 15 deletions
diff --git a/src/components/include/application_manager/application_manager.h b/src/components/include/application_manager/application_manager.h
index 6d5c7607cc..057f38f78e 100644
--- a/src/components/include/application_manager/application_manager.h
+++ b/src/components/include/application_manager/application_manager.h
@@ -47,11 +47,6 @@
#include "application_manager/plugin_manager/rpc_plugin_manager.h"
#include "application_manager/state_controller.h"
#include "policy/policy_types.h"
-#include "telemetry_monitor/telemetry_observable.h"
-
-namespace resumption {
-class LastState;
-}
namespace app_launch {
class AppLaunchCtrl;
@@ -136,10 +131,14 @@ class ApplicationManager {
public:
virtual ~ApplicationManager() {}
+ DEPRECATED
+ virtual bool Init(resumption::LastState&,
+ media_manager::MediaManager* media_manager) = 0;
+
/**
* Inits application manager
*/
- virtual bool Init(resumption::LastState& last_state,
+ virtual bool Init(resumption::LastStateWrapperPtr last_state_wrapper,
media_manager::MediaManager* media_manager) = 0;
/**
@@ -286,17 +285,17 @@ class ApplicationManager {
virtual void set_current_audio_source(const uint32_t source) = 0;
/**
* @brief OnHMILevelChanged the callback that allows SDL to react when
* application's HMI level has been changed.
*
* @param app_id application identifier for which HMILevel has been chaned.
*
* @param from previous HMILevel.
* @param to current HMILevel.
*/
- virtual void OnHMILevelChanged(uint32_t app_id,
- mobile_apis::HMILevel::eType from,
- mobile_apis::HMILevel::eType to) = 0;
+ virtual void OnHMIStateChanged(const uint32_t app_id,
+ const HmiStatePtr from,
+ const HmiStatePtr to) = 0;
/**
* @brief Updates streaming service status for specified session and notifies
@@ -619,12 +618,13 @@ class ApplicationManager {
mobile_api::AppInterfaceUnregisteredReason::eType reason) = 0;
/**
- * @brief Checks HMI level and returns true if streaming is allowed
+ * @brief Checks application HMI state and returns true if streaming is
+ * allowed
* @param app_id Application id
* @param service_type Service type to check
* @return True if streaming is allowed, false in other case
*/
- virtual bool HMILevelAllowsStreaming(
+ virtual bool HMIStateAllowsStreaming(
uint32_t app_id, protocol_handler::ServiceType service_type) const = 0;
/**
@@ -286,17 +285,17 @@ class ApplicationManager {
virtual void set_current_audio_source(const uint32_t source) = 0;
/**
- * @brief OnHMILevelChanged the callback that allows SDL to react when
+ * @brief OnHMIStateChanged the callback that allows SDL to react when
* application's HMI level has been changed.
*
@@ -286,17 +285,17 @@ class ApplicationManager {
* application's HMI level has been changed.
*
- * @param app_id application identifier for which HMILevel has been chaned.
+ * @param app_id application identifier for which HMIState has been chaned.
*
@@ -286,17 +285,17 @@ class ApplicationManager {
*
- * @param from previous HMILevel.
- * @param to current HMILevel.
+ * @param from previous HMIState.
+ * @param to current HMIState.
*/